A deterministic synthetic cube for examples and tests, shaped like an
hsi_cube so the art functions can be demonstrated without hyperspectR
or any recorded data.
Examples
cube <- hsa_demo_cube()
dim(cube$data)
#> [1] 48 64 24
A deterministic synthetic cube for examples and tests, shaped like an
hsi_cube so the art functions can be demonstrated without hyperspectR
or any recorded data.
cube <- hsa_demo_cube()
dim(cube$data)
#> [1] 48 64 24